/**
 * @since 1.0.0
 */
import { type DeleteThingShadowCommandInput, type DeleteThingShadowCommandOutput, type GetRetainedMessageCommandInput, type GetRetainedMessageCommandOutput, type GetThingShadowCommandInput, type GetThingShadowCommandOutput, type IoTDataPlaneClient, type IoTDataPlaneClientConfig, type ListNamedShadowsForThingCommandInput, type ListNamedShadowsForThingCommandOutput, type ListRetainedMessagesCommandInput, type ListRetainedMessagesCommandOutput, type PublishCommandInput, type PublishCommandOutput, type UpdateThingShadowCommandInput, type UpdateThingShadowCommandOutput } from "@aws-sdk/client-iot-data-plane";
import type { HttpHandlerOptions, SdkError, ServiceLogger } from "@effect-aws/commons";
import { Effect, Layer } from "effect";
import type { ConflictError, InternalFailureError, InvalidRequestError, MethodNotAllowedError, RequestEntityTooLargeError, ResourceNotFoundError, ServiceUnavailableError, ThrottlingError, UnauthorizedError, UnsupportedDocumentEncodingError } from "./Errors.js";
import * as Instance from "./IoTDataPlaneClientInstance.js";
interface IoTDataPlaneService$ {
    readonly _: unique symbol;
    /**
     * @see {@link DeleteThingShadowCommand}
     */
    deleteThingShadow(args: DeleteThingShadowCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteThingShadowCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError>;
    /**
     * @see {@link GetRetainedMessageCommand}
     */
    getRetainedMessage(args: GetRetainedMessageCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetRetainedMessageCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link GetThingShadowCommand}
     */
    getThingShadow(args: GetThingShadowCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetThingShadowCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError>;
    /**
     * @see {@link ListNamedShadowsForThingCommand}
     */
    listNamedShadowsForThing(args: ListNamedShadowsForThingCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListNamedShadowsForThingCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link ListRetainedMessagesCommand}
     */
    listRetainedMessages(args: ListRetainedMessagesCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListRetainedMessagesCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ServiceUnavailableError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link PublishCommand}
     */
    publish(args: PublishCommandInput, options?: HttpHandlerOptions): Effect.Effect<PublishCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link UpdateThingShadowCommand}
     */
    updateThingShadow(args: UpdateThingShadowCommandInput, options?: HttpHandlerOptions): Effect.Effect<UpdateThingShadowCommandOutput, SdkError | ConflictError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | RequestEntityTooLargeError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeIoTDataPlaneService: Effect.Effect<IoTDataPlaneService$, never, Instance.IoTDataPlaneClientInstance>;
declare const IoTDataPlaneService_base: import("effect/Context").TagClass<IoTDataPlaneService, "@effect-aws/client-iot-data-plane/IoTDataPlaneService", IoTDataPlaneService$> & Effect.Tag.Proxy<IoTDataPlaneService, IoTDataPlaneService$> & {
    use: <X>(body: (_: IoTDataPlaneService$) => X) => [X] extends [Effect.Effect<infer A, infer E, infer R>] ? Effect.Effect<A, E, IoTDataPlaneService | R> : [X] extends [PromiseLike<infer A_1>] ? Effect.Effect<A_1, import("effect/Cause").UnknownException, IoTDataPlaneService> : Effect.Effect<X, never, IoTDataPlaneService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class IoTDataPlaneService extends IoTDataPlaneService_base {
    static readonly defaultLayer: Layer.Layer<IoTDataPlaneService, never, never>;
    static readonly layer: (config: IoTDataPlaneService.Config) => Layer.Layer<IoTDataPlaneService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: IoTDataPlaneClientConfig) => IoTDataPlaneClient) => Layer.Layer<IoTDataPlaneService, never, never>;
}
/**
 * @since 1.0.0
 */
export declare namespace IoTDataPlaneService {
    /**
     * @since 1.0.0
     */
    interface Config extends Omit<IoTDataPlaneClientConfig, "logger"> {
        readonly logger?: ServiceLogger.ServiceLoggerConstructorProps | true;
    }
}
export {};
//# sourceMappingURL=IoTDataPlaneService.d.ts.map