/**
 * @since 1.0.0
 */
import { DeleteThingShadowCommand, GetRetainedMessageCommand, GetThingShadowCommand, ListNamedShadowsForThingCommand, ListRetainedMessagesCommand, PublishCommand, UpdateThingShadowCommand, } from "@aws-sdk/client-iot-data-plane";
import { Service } from "@effect-aws/commons";
import { Effect, Layer } from "effect";
import { AllServiceErrors } from "./Errors.js";
import * as Instance from "./IoTDataPlaneClientInstance.js";
import * as IoTDataPlaneServiceConfig from "./IoTDataPlaneServiceConfig.js";
const commands = {
    DeleteThingShadowCommand,
    GetRetainedMessageCommand,
    GetThingShadowCommand,
    ListNamedShadowsForThingCommand,
    ListRetainedMessagesCommand,
    PublishCommand,
    UpdateThingShadowCommand,
};
/**
 * @since 1.0.0
 * @category constructors
 */
export const makeIoTDataPlaneService = Effect.gen(function* () {
    const client = yield* Instance.IoTDataPlaneClientInstance;
    return Service.fromClientAndCommands(client, commands, {
        errorTags: AllServiceErrors,
        resolveClientConfig: IoTDataPlaneServiceConfig.toIoTDataPlaneClientConfig,
    });
});
/**
 * @since 1.0.0
 * @category models
 */
export class IoTDataPlaneService extends Effect.Tag("@effect-aws/client-iot-data-plane/IoTDataPlaneService")() {
    static defaultLayer = Layer.effect(this, makeIoTDataPlaneService).pipe(Layer.provide(Instance.layer));
    static layer = (config) => Layer.effect(this, makeIoTDataPlaneService).pipe(Layer.provide(Instance.layer), Layer.provide(IoTDataPlaneServiceConfig.setIoTDataPlaneServiceConfig(config)));
    static baseLayer = (evaluate) => Layer.effect(this, makeIoTDataPlaneService).pipe(Layer.provide(Layer.effect(Instance.IoTDataPlaneClientInstance, Effect.map(IoTDataPlaneServiceConfig.toIoTDataPlaneClientConfig, evaluate))));
}
//# sourceMappingURL=IoTDataPlaneService.js.map