import { ServiceLogger } from "@effect-aws/commons";
import { Effect, FiberRef, Layer } from "effect";
import { dual } from "effect/Function";
import { globalValue } from "effect/GlobalValue";
/**
 * @since 1.0.0
 * @category iot-data-plane service config
 */
const currentIoTDataPlaneServiceConfig = globalValue("@effect-aws/client-iot-data-plane/currentIoTDataPlaneServiceConfig", () => FiberRef.unsafeMake({}));
/**
 * @since 1.0.0
 * @category iot-data-plane service config
 */
export const withIoTDataPlaneServiceConfig = dual(2, (effect, config) => Effect.locally(effect, currentIoTDataPlaneServiceConfig, config));
/**
 * @since 1.0.0
 * @category iot-data-plane service config
 */
export const setIoTDataPlaneServiceConfig = (config) => Layer.locallyScoped(currentIoTDataPlaneServiceConfig, config);
/**
 * @since 1.0.0
 * @category adapters
 */
export const toIoTDataPlaneClientConfig = Effect.gen(function* () {
    const { logger: serviceLogger, ...config } = yield* FiberRef.get(currentIoTDataPlaneServiceConfig);
    const logger = serviceLogger === true
        ? yield* ServiceLogger.toClientLogger(ServiceLogger.defaultServiceLogger)
        : (serviceLogger ? yield* ServiceLogger.toClientLogger(ServiceLogger.make(serviceLogger)) : undefined);
    return { logger, ...config };
});
//# sourceMappingURL=IoTDataPlaneServiceConfig.js.map